@@ -1,16 +1,16 @@
 package File::Move::Undoable;
 
-our $DATE = '2015-09-03'; # DATE
-our $VERSION = '0.06'; # VERSION
+our $DATE = '2016-06-09'; # DATE
+our $VERSION = '0.07'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
 use Log::Any::IfLOG '$log';
 
-use Builtin::Logged qw(system);
 use File::MoreUtil qw(file_exists l_abs_path);
 use File::Trash::Undoable;
+use IPC::System::Options 'system', -log=>1;
 use Proc::ChildError qw(explain_child_error);
 
 our %SPEC;
@@ -176,22 +176,7 @@ File::Move::Undoable - Move file/directory using rename/rsync, with undo support
 
 =head1 VERSION
 
-This document describes version 0.06 of File::Move::Undoable (from Perl distribution File-Move-Undoable), released on 2015-09-03.
-
-=head1 FAQ
-
-=head2 Why do you use rsync? Why not, say, File::Copy::Recursive?
-
-With C<rsync>, we can continue interrupted transfer. We need this ability for
-recovery. Also, C<rsync> can handle hardlinks and preservation of ownership,
-something which L<File::Copy::Recursive> currently does not do. And, being
-implemented in C, it might be faster when processing large files/trees.
-
-=head1 SEE ALSO
-
-L<Setup>
-
-L<Rinci::Transaction>
+This document describes version 0.07 of File::Move::Undoable (from Perl distribution File-Move-Undoable), released on 2016-06-09.
 
 =head1 FUNCTIONS
 
@@ -216,6 +201,8 @@ Unfixable state: C<source> does not exist, or both C<source> and C<target> exist
 (unless we are moving to a different filesystem, in which it means an
 interrupted transfer and thus fixable).
 
+This function is not exported.
+
 This function is idempotent (repeated invocations with same arguments has the same effect as single invocation). This function supports transactions.
 
 
@@ -280,6 +267,15 @@ that contains extra information.
 
 Return value:  (any)
 
+=head1 FAQ
+
+=head2 Why do you use rsync? Why not, say, File::Copy::Recursive?
+
+With C<rsync>, we can continue interrupted transfer. We need this ability for
+recovery. Also, C<rsync> can handle hardlinks and preservation of ownership,
+something which L<File::Copy::Recursive> currently does not do. And, being
+implemented in C, it might be faster when processing large files/trees.
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/File-Move-Undoable>.
@@ -296,13 +292,19 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+L<Setup>
+
+L<Rinci::Transaction>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
